@@ -580,6 +580,7 @@ class Sandbox(SandboxSetup, SandboxApi):
     
     def get_instance_auth_info(  # type: ignore
         self,
+        valid_time: Optional[int] = 3600,
         request_timeout: Optional[float] = None,
     ) -> InstanceAuthInfo:
         """
@@ -596,6 +597,7 @@ class Sandbox(SandboxSetup, SandboxApi):
 
         return SandboxApi.get_instance_auth_info(
             sandbox_id=self.sandbox_id,
+            valid_time=valid_time,
             **config_dict,
         )
 
